NetticaPy
=========

NetticaPy is a python wrapper around Nettica_'s `SOAP DNS API`_.
It supports CRUD operations on domain records, reading the nettica
service information (your account settings) and listing zones (
your mapped domains).

I wanted to gain scriptable DNS control over existing zones only.
Feel free to add further zone support (create, update, delete and create
a secondary zone) and/or template support. Those are available as SOAP
endpoints as well.

.. _Nettica: http://www.nettica.com/
.. _SOAP DNS API: https://www.nettica.com/DNS/DnsApi.asmx
